@@ -2,7 +2,7 @@
 __author__ = "Laurent P. René de Cotret"
 __email__ = "laurent.renedecotret@mail.mcgill.ca"
 __license__ = "GPLv3"
-__version__ = "2.1.10"
+__version__ = "2.1.11"
 
 from .affine import (
     affine_map,
@@ -45,12 +45,14 @@ from .image import (
     align,
     autocenter,
     azimuthal_average,
+    brillouin_zones,
     combine_masks,
     detector_scattvectors,
     ialign,
     isnr,
     itrack_peak,
     bragg_peaks,
+    bragg_peaks_persistence,
     mask_from_collection,
     mask_image,
     nfold,
