@@ -2,9 +2,10 @@
 """ Diffraction image analysis """
 
 from .alignment import align, ialign, itrack_peak
+from .brillouin import brillouin_zones
 from .calibration import detector_scattvectors, powder_calq
 from .center import autocenter
-from .indexing import bragg_peaks
+from .indexing import bragg_peaks, bragg_peaks_persistence
 from .metrics import (
     combine_masks,
     isnr,
