@@ -13,11 +13,16 @@ else:
     WITH_PYQTGRAPH = True
 
 
-# This is weird, but PyQtGraph is an optional dependency
-# Therefore, we cannot define this class unless PyQtGraph is importable
 if WITH_PYQTGRAPH:
 
-    class Diffshow(pg.QtWidgets.QWidget):
+    # This is weird, but PyQtGraph is an optional dependency
+    # Therefore, we cannot define this class unless PyQtGraph is importable
+    if hasattr(pg, "QtWidgets"):
+        BASE_CLASS = pg.QtWidgets
+    elif hasattr(pg, "QtGui"):
+        BASE_CLASS = pg.QtGui
+
+    class Diffshow(BASE_CLASS.QWidget):
         """
         Widget containing a main viewer, plus some cursor information.
 
