@@ -2,6 +2,8 @@
 
 from pathlib import Path
 
+import numpy as np
+
 from .dm import dmread
 from .merlin import mibread
 
@@ -18,6 +20,8 @@ def diffread(fname):
 
         * TIFF (`*.tif`, `*.tiff`)
 
+        * NumPy (`*.npy`)
+
         * All file formats supported by Scikit-image
 
     Parameters
@@ -42,6 +46,8 @@ def diffread(fname):
         return mibread(fname)
     elif fname.suffix in {".dm3", ".dm4"}:
         return dmread(fname)
+    elif fname.suffix == ".npy":
+        return np.load(fname, fix_imports=False)
 
     # Worst-case scenario, we need skimage.io
     # since this is a slow import, we import it here
